Package: ChIPanalyser
Type: Package
Title: ChIPanalyser: Predicting Transcription Factor Binding Sites
Authors@R: c(
    person(c("Patrick", "CN"), "Martin", role=c("cre", "aut"), email="pcnmartin@gmail.com"),
    person(c("Nicolea","Radu"), "Zabet", role="aut"))
Version: 1.33.0
Date: 2017-09-01
Author: Patrick C.N.Martin & Nicolae Radu Zabet
Maintainer: Patrick C.N. Martin <pcnmartin@gmail.com>
Citation: Zabet NR, Adryan B (2015) Estimating binding properties of
        transcription factors from genome-wide binding profiles.
        Nucleic Acids Res., 43, 84–94.
Description: ChIPanalyser is a package to predict and understand TF binding
    by utilizing a statistical thermodynamic model. The model incorporates 4
    main factors thought to drive TF binding: Chromatin State, Binding energy,
    Number of bound molecules and a scaling factor modulating TF binding
    affinity. Taken together, ChIPanalyser produces ChIP-like profiles that
    closely mimic the patterns seens in real ChIP-seq data. 
License: GPL-3
Collate: 2AllS4Class_ProfileParameters.R 3AllGenerics.R 4AllMethods.R
        AllInitialize.R AllShowMethods.R computeChIPProfile.R
        computeOccupancy.R computeOptimal.R computePWMScore.R
        computeGenomeWide.R parallelInternalFunctionsDev.R
        GenomicProfileGenericFunctions.R plotOccupancy.R
        plotOptimalHeatMapDev.R DataPreprocessingDev.R
        DataPreprocessingGenericFunctionsDev.R
        profileAccuracyEstimateDev.R GAAnalysis.R GAGeneric.R
Depends: R (>= 3.5.0),GenomicRanges, Biostrings, BSgenome, RcppRoll,
        parallel
Imports: methods, IRanges,
        S4Vectors,grDevices,graphics,stats,utils,rtracklayer,ROCR,
        BiocManager,GenomeInfoDb,RColorBrewer
Suggests: BSgenome.Dmelanogaster.UCSC.dm6,knitr, RUnit, BiocGenerics
Encoding: UTF-8
LazyData: true
biocViews: Software, BiologicalQuestion, WorkflowStep, Transcription,
        Sequencing, ChipOnChip, Coverage, Alignment, ChIPSeq,
        SequenceMatching, DataImport ,PeakDetection
VignetteBuilder: knitr
RoxygenNote: 7.2.1
git_url: https://git.bioconductor.org/packages/ChIPanalyser
git_branch: devel
git_last_commit: 873269e
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-04 22:00:35 UTC; biocbuild
