import("GenomicRanges","Biostrings", "BSgenome","RcppRoll","parallel",
    "rtracklayer","BiocManager","GenomeInfoDb")

importFrom("grDevices", "colorRampPalette", "heat.colors","as.raster","rainbow")
importFrom("RColorBrewer","brewer.pal")
importFrom("graphics", "axis", "box", "contour", "image", "lines",
    "par", "plot", "polygon", "rect", "text", "title","segments","legend",
    "rasterImage")
importFrom("methods", "new", "validObject","is")
importFrom("stats", "cor", "dgamma","sd","na.omit","median","ks.test",
    "quantile","runif")
importFrom("utils", "read.table","write.table")
importFrom("IRanges","IRanges")
importFrom("rtracklayer","import")
importFrom("S4Vectors","queryHits")
importFrom("ROCR","prediction","performance")
importFrom("GenomeInfoDb","seqlevels","dropSeqlevels")
importFrom("methods", "slot", "slot<-", "slotNames")



exportPattern("^[[:alpha:]]+")
exportMethods(
    "averageExpPWMScore",
    "backgroundSignal",
    "backgroundSignal<-",
    "boundMolecules",
    "boundMolecules<-",
    "BPFrequency",
    "BPFrequency<-",
    "chipMean",
    "chipMean<-",
    "chipSd",
    "chipSd<-",
    "chipSmooth",
    "chipSmooth<-",
    "DNASequenceLength",
    "drop",
    "initialize",
    "lambdaPWM",
    "lambdaPWM<-",
    "loci",
    "lociWidth",
    "lociWidth<-",
    "maxPWMScore",
    "maxSignal",
    "maxSignal<-",
    "minPWMScore",
    "naturalLog",
    "naturalLog<-",
    "noiseFilter",
    "noiseFilter<-",
    "noOfSites",
    "noOfSites<-",
    "PFMFormat",
    "PFMFormat<-",
    "ploidy",
    "ploidy<-",
    "PositionFrequencyMatrix",
    "PositionFrequencyMatrix<-",
    "PositionWeightMatrix",
    "PositionWeightMatrix<-",
    "profiles",
    "PWMpseudocount",
    "PWMpseudocount<-",
    "PWMThreshold",
    "PWMThreshold<-",
    "removeBackground",
    "removeBackground<-",
    "scores",
    "show",
    "stepSize",
    "stepSize<-",
    "strandRule",
    "strandRule<-",
    "whichstrand",
    "whichstrand<-"
)
exportClasses(
    "loci",
     "genomicProfiles",
     "genomicProfilesInternal",
     "parameterOptions",
     "ChIPScore",
     "GRList",
     "nos"
)
