\name{PositionWeightMatrix<--methods}
\docType{methods}

\alias{PositionWeightMatrix<--methods}
\title{ ~~ Methods for Function \code{PositionWeightMatrix<-}  ~~}
\description{
Setter Method for the \code{PositionWeightMatrix} slot in a
\code{\link{genomicProfiles}} object
}
\section{Methods}{
\describe{

\item{\code{PositionWeightMatrix(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
