\name{scores-methods}
\docType{methods}

\alias{scores-methods}
\title{ ~~ Methods for Function \code{scores}  ~~}
\description{
Accessor method for \code{scores} slot in a \code{ChIPScore} object.
}
\section{Methods}{
\describe{

\item{\code{scores(object)}}{
Extracted and normalised ChIP scores at loci of interest.
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
