\name{PositionFrequencyMatrix<--methods}
\docType{methods}

\alias{PositionFrequencyMatrix<--methods}

\title{ ~~ Methods for Function \code{PositionFrequencyMatrix<-}  ~~}
\description{
Setter method for the \code{PFM} slot in a
\code{\link{genomicProfiles}} object
}
\section{Methods}{
\describe{

\item{\code{PositionFrequencyMatrix(object)<-"path/to/file/"}}{
%%  ~~describe this method here~~
}

\item{\code{PositionFrequencyMatrix(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
