\name{PWMpseudocount<--methods}
\docType{methods}

\alias{PWMpseudocount<--methods}

\title{ ~~ Methods for Function \code{PWMpseudocount<-}  ~~}
\description{
Setter Method for the \code{pseudocount} slot in a
\code{\link{parameterOptions}} object
}
\section{Methods}{
\describe{

\item{\code{PWMpseudocount(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
