\name{lociWidth<--methods}
\docType{methods}

\alias{lociWidth<--methods}
\title{ ~~ Methods for Function \code{lociWidth<-}  ~~}
\description{
Setter method for the \code{loci} slot in \code{\linkS4class{ChIPScore}}
}
\section{Methods}{
\describe{

\item{\code{lociWidth(Object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
