\name{noiseFilter<--methods}
\docType{methods}

\alias{noiseFilter<--methods}

\title{ ~~ Methods for Function \code{noiseFilter<-}  ~~}
\description{
Setter method for \code{noiseFilter}
}
\section{Methods}{
\describe{

\item{\code{noiseFilter(object)<-value}}{
Noise Filter that will be applied to ChIP scores
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
