\name{backgroundSignal<--methods}
\docType{methods}
\alias{backgroundSignal<--methods}

\title{ ~~ Methods for Function \code{backgroundSignal<-}  ~~}
\description{
 ~~ Methods for function \code{backgroundSignal<-}  ~~
}
\section{Methods}{
\describe{

\item{\code{backgroundSignal(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
