\name{whichstrand-methods}
\docType{methods}

\alias{whichstrand-methods}
\title{ ~~ Methods for Function \code{whichstrand}  ~~}
\description{
Accessor method for the \code{whichstrand} slot in a
\code{\linkS4class{parameterOptions}} object
}
\section{Methods}{
\describe{

\item{\code{whichstrand(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
