\name{stepSize-methods}
\docType{methods}

\alias{stepSize-methods}
\title{ ~~ Methods for Function \code{stepSize}  ~~}
\description{
Accessor method of the \code{stepSize} slot in
\code{\linkS4class{parameterOptions}} object
}
\section{Methods}{
\describe{

\item{\code{stepSize(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
