\name{initialize-methods}
\docType{methods}
\alias{initialize-methods}
\alias{initialize,ChIPScore-method}
\alias{initialize,genomicProfiles-method}
\alias{initialize,parameterOptions-method}
\title{ ~~ Methods for Function \code{initialize}  ~~}
\description{
 ~~ Methods for function \code{initialize}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(.Object = "ChIPScore")}}{
Initialize ChIPScore
}

\item{\code{signature(.Object = "genomicProfiles")}}{
Initialize genomicProfiles
}

\item{\code{signature(.Object = "parameterOptions")}}{
Initialize parameterOptions
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
