\name{show-methods}
\docType{methods}
\alias{show-methods}
\alias{show,ChIPScore-method}
\alias{show,genomicProfiles-method}
\alias{show,parameterOptions-method}
\title{ ~~ Methods for Function \code{show}  ~~}
\description{
Show methods for various objects
}
\section{Methods}{
\describe{

\item{\code{signature(object = "ChIPScore")}}{
%%  ~~describe this method here~~
}

\item{\code{signature(object = "genomicProfiles")}}{
%%  ~~describe this method here~~
}

\item{\code{signature(object = "parameterOptions")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
