\name{ploidy<--methods}
\docType{methods}

\alias{ploidy<--methods}

\title{ ~~ Methods for Function \code{ploidy<-}  ~~}
\description{
Setter Method for the \code{ploidy} slot in an
\code{\link{parameterOptions}} object
}
\section{Methods}{
\describe{

\item{\code{ploidy(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
