\name{PFMFormat-methods}
\docType{methods}

\alias{PFMFormat-methods}

\title{ ~~ Methods for Function \code{PFMFormat}  ~~}
\description{
Accesor method for the \code{PFMFormat} slot in a
\code{\link{genomicProfiles}} object
}
\section{Methods}{
\describe{

\item{\code{PFMFormat(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
