\name{maxSignal-methods}
\docType{methods}

\alias{maxSignal-methods}

\title{ ~~ Methods for Function \code{maxSignal}  ~~}
\description{
Accessor method for \code{maxSignal}
}
\section{Methods}{
\describe{

\item{\code{maxSignal(object)}}{
Maximum ChIP signal extracted from ChIP data (see \code{processingChIP})
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
