\name{lambdaPWM<--methods}
\docType{methods}

\alias{lambdaPWM<--methods}
\title{ ~~ Methods for Function \code{lambdaPWM<-}  ~~}
\description{
Setter method for the \code{lambdaPWM} slot in the \code{parameterOptions}
}
\section{Methods}{
\describe{

\item{\code{lambdaPWM(object)<-value}}{

}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
