\name{ploidy-methods}
\docType{methods}

\alias{ploidy-methods}

\title{ ~~ Methods for Function \code{ploidy}  ~~}
\description{
Accessor method for the \code{ploidy} slot in a
\code{\link{parameterOptions}} object
}
\section{Methods}{
\describe{

\item{\code{ploidy(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
