\name{lambdaPWM-methods}
\docType{methods}

\alias{lambdaPWM-methods}

\title{ ~~ Methods for Function \code{lambdaPWM}  ~~}
\description{
 ~~ Methods for function \code{lambdaPWM}  ~~
}
\section{Methods}{
\describe{

\item{\code{lambdaPWM(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
