\name{lociWidth-methods}
\docType{methods}

\alias{lociWidth-methods}
\title{ ~~ Methods for Function \code{lociWidth}  ~~}
\description{
Accessor method for the \code{loci} slot in \code{\linkS4class{ChIPScore}}
}
\section{Methods}{
\describe{

\item{\code{lociWidth(object)}}{
Setting width of regions when using the reduce argument and NOT providing your
own loci when using the \code{processingChIP} function.
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
