\name{chipSd-methods}
\docType{methods}

\alias{chipSd-methods}

\title{ ~~ Methods for Function \code{chipSd}  ~~}
\description{
 ~~ Methods for function \code{chipSd}  ~~
}
\section{Methods}{
\describe{

\item{\code{chipSd(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
