\name{chipSmooth<--methods}
\docType{methods}

\alias{chipSmooth<--methods}

\title{ ~~ Methods for Function \code{chipSmooth<-}  ~~}
\description{
 ~~ Methods for function \code{chipSmooth<-}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(object = "parameterOptions", value = "vector")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
