\name{maxSignal<--methods}
\docType{methods}

\alias{maxSignal<--methods}
\title{ ~~ Methods for Function \code{maxSignal<-}  ~~}
\description{
Setter method for \code{maxSignal}
}
\section{Methods}{
\describe{

\item{\code{maxSignal(Object)<-value}}{
Maximum ChIP signal extracted from ChIP data (see \code{processingChIP})
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
