\name{PositionWeightMatrix-methods}
\docType{methods}

\alias{PositionWeightMatrix-methods}
\title{ ~~ Methods for Function \code{PositionWeightMatrix}  ~~}
\description{
Accessor Method for the \code{PWM} slot in a
\code{\link{genomicProfiles}} object
}
\section{Methods}{
\describe{

\item{\code{PositionWeightMatrix(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
