\name{DNASequenceLength-methods}
\docType{methods}
\alias{DNASequenceLength-methods}

\title{ ~~ Methods for Function \code{DNASequenceLength}  ~~}
\description{
 ~~ Methods for function \code{DNASequenceLength}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(object = "genomicProfilesInternal")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
