\name{noOfSites-methods}
\docType{methods}

\alias{noOfSites-methods}

\title{ ~~ Methods for Function \code{noOfSites}  ~~}
\description{
 ~~ Methods for function \code{noOfSites}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(object = "parameterOptions")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
