\name{averageExpPWMScore-methods}
\docType{methods}
\alias{averageExpPWMScore-methods}

\title{ ~~ Methods for Function \code{averageExpPWMScore}  ~~}
\description{
 ~~ Methods for function \code{averageExpPWMScore}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(object = "genomicProfilesInternal")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
