\name{loci-methods}
\docType{methods}
\alias{loci-methods}


\title{ ~~ Methods for Function \code{loci}  ~~}
\description{
Accessor method for the \code{loci} slot in \code{\linkS4class{ChIPScore}}
}
\section{Methods}{
\describe{

\item{\code{loci{Object}}}{
Loci of interest parsed to or extracted from the ChIPScore object
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
