\name{backgroundSignal-methods}
\alias{backgroundSignal-methods}

\docType{methods}

\title{ ~~ Methods for Function \code{backgroundSignal}  ~~}
\description{
 ~~ Methods for function \code{backgroundSignal}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(object = "parameterOptions")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
