\name{minPWMScore-methods}
\docType{methods}

\alias{minPWMScore-methods}
\title{ ~~ Methods for Function \code{minPWMScore}  ~~}
\description{
Accessor for \code{minPWMScore}
}
\section{Methods}{
\describe{

\item{\code{minPWMScore(object)}}{
Minimum PWM score computed during the \code{computeGenomeWideScores} step.
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
