\name{naturalLog<--methods}
\docType{methods}

\alias{naturalLog<--methods}
\title{ ~~ Methods for Function \code{naturalLog<-}  ~~}
\description{
Setter method for the \code{naturalLog} slot in a
\code{\link{parameterOptions}} object.
}
\section{Methods}{
\describe{

\item{\code{naturalLog(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
