\name{PositionFrequencyMatrix-methods}
\docType{methods}

\alias{PositionFrequencyMatrix-methods}
\title{ ~~ Methods for Function \code{PositionFrequencyMatrix}  ~~}
\description{
Accessor method for the \code{PFM} slot in a
\code{genomicProfiles} object
}
\section{Methods}{
\describe{

\item{\code{PositionFrequencyMatrix(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
