\name{boundMolecules<--methods}
\docType{methods}
\alias{boundMolecules<--methods}

\title{ ~~ Methods for Function \code{boundMolecules<-}  ~~}
\description{
 ~~ Methods for function \code{boundMolecules<-}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(object = "parameterOptions", value = "vector")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
