\name{PFMFormat<--methods}
\docType{methods}

\alias{PFMFormat<--methods}
\title{ ~~ Methods for Function \code{PFMFormat<-}  ~~}
\description{
Setter method for the \code{PFMFormat} slot in a
\code{\link{genomicProfiles}} object
}
\section{Methods}{
\describe{

\item{\code{PFMFormat(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
