\name{strandRule-methods}
\docType{methods}

\alias{strandRule-methods}
\title{ ~~ Methods for Function \code{strandRule}  ~~}
\description{
Accessor Method for the \code{strandRule} slot in a
\code{\linkS4class{parameterOptions}} object
}
\section{Methods}{
\describe{

\item{\code{strandRule(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
