\name{strandRule<--methods}
\docType{methods}

\alias{strandRule<--methods}
\title{ ~~ Methods for Function \code{strandRule<-}  ~~}
\description{
Setter method for the \code{strandRule} slot in a
\code{\linkS4class{parameterOptions}} object.
}
\section{Methods}{
\describe{

\item{\code{strandRule(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
