\name{removeBackground<--methods}
\docType{methods}

\alias{removeBackground<--methods}
\title{ ~~ Methods for Function \code{removeBackground<-}  ~~}
\description{
Setter Method for the \code{removeBackground} slot in a
\code{parameterOptions} object
}
\section{Methods}{
\describe{

\item{\code{removeBackground(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
