\name{maxPWMScore-methods}
\docType{methods}

\alias{maxPWMScore-methods}

\title{ ~~ Methods for Function \code{maxPWMScore}  ~~}
\description{
Accessor method for \code{maxPWMScore}
}
\section{Methods}{
\describe{

\item{\code{maxPWMScore(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
