\name{PWMpseudocount-methods}
\docType{methods}

\alias{PWMpseudocount-methods}
\title{ ~~ Methods for Function \code{PWMpseudocount}  ~~}
\description{
Accessor Method for a \code{PWMpseudocount} slot in a
\code{\link{parameterOptions}}
}
\section{Methods}{
\describe{

\item{\code{PWMpseudocount(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
