\name{stepSize<--methods}
\docType{methods}

\alias{stepSize<--methods}
\title{ ~~ Methods for Function \code{stepSize<-}  ~~}
\description{
Setter Method for the \code{stepSize} slot in a
\code{\linkS4class{parameterOptions}}
}
\section{Methods}{
\describe{

\item{\code{stepSize(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
