\name{BPFrequency<--methods}

\alias{BPFrequency<--methods}
\docType{methods}

\title{ ~~ Methods for Function \code{BPFrequency<-}  ~~}
\description{
 ~~ Methods for function \code{BPFrequency<-}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(object = "genomicProfilesInternal", value = "DNAStringSet")}}{
%%  ~~describe this method here~~
}

\item{\code{signature(object = "genomicProfilesInternal", value = "vector")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
