\name{removeBackground-methods}
\docType{methods}

\alias{removeBackground-methods}
\title{ ~~ Methods for Function \code{removeBackground}  ~~}
\description{
Accessor Method for the \code{removeBackground} slot in a
\code{\link{parameterOptions}} object
}
\section{Methods}{
\describe{

\item{\code{removeBackground(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
