\name{chipMean-methods}
\docType{methods}
\alias{chipMean-methods}

\title{ ~~ Methods for Function \code{chipMean}  ~~}
\description{
 ~~ Methods for function \code{chipMean}  ~~
}
\section{Methods}{
\describe{

\item{\code{chipMean(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
