\name{noOfSites<--methods}
\docType{methods}

\alias{noOfSites<--methods}

\title{ ~~ Methods for Function \code{noOfSites<-}  ~~}
\description{
Setter method for \code{noOfSites}
}
\section{Methods}{
\describe{

\item{\code{noOfSites(object)<-"all" }}{
%%  ~~describe this method here~~
}

\item{\code{noOfSites(object)<-value}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
