\name{drop-methods}
\docType{methods}

\alias{drop-methods}
\title{ ~~ Methods for Function \code{drop}  ~~}
\description{
 ~~ Methods for function \code{drop}  ~~
}
\section{Methods}{
\describe{

\item{\code{signature(object = "genomicProfilesInternal")}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
