\name{profiles-methods}
\docType{methods}
\alias{profiles}
\title{ ~~ Methods for Function \code{profiles}  ~~}
\description{
Accessor method for \code{profiles} in a \code{\link{genomicProfiles}} object
}
\section{Methods}{
\describe{

\item{\code{profiles(oject)}}{
Computed PWM scores, Occupancy or ChIP-seq like profiles for loci of interest and
paramter combination of interest.
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
