\name{PWMThreshold-methods}
\docType{methods}

\alias{PWMThreshold-methods}

\title{ ~~ Methods for Function \code{PWMThreshold}  ~~}
\description{
Accessor method for the \code{PWMThreshold} slot in  a
\code{\link{parameterOptions}} object
}
\section{Methods}{
\describe{

\item{\code{PWMThreshold(object)}}{
%%  ~~describe this method here~~
}
}}
\keyword{methods}
\keyword{ ~~ other possible keyword(s) ~~ }
